@@ -6,8 +6,8 @@ HWT_KEYWORDS = keyword.kwlist + [
     # imports
     'hwt', 'Unit', "Param", "Signal",
     "Concat", "If", "Switch",
-    "HArray", "HArrayVal", "Bits", "INT", "SLICE", "FLOAT64",
-    "HEnum", "SliceVal", "_", "rename_signal",
+    "HArray", "Bits", "INT", "SLICE", "STR", "BIT", "FLOAT64",
+    "HEnum", "_", "rename_signal",
 ]
 
 if sys.version_info[0] <= 2:
